==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/fluidrelay/kotlin/inputs/CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.fluidrelay.kotlin.inputs

import com.pulumi.azurenative.fluidrelay.inputs.CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs.builder
import com.pulumi.azurenative.fluidrelay.kotlin.enums.CmkIdentityType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * All identity configuration for Customer-managed key settings defining which identity should be used to auth to Key Vault.
 * @property identityType Values can be SystemAssigned or UserAssigned
 * @property userAssignedIdentityResourceId user assigned identity to use for accessing key encryption key Url. Ex: /subscriptions/fa5fc227-a624-475e-b696-cdd604c735bc/resourceGroups/<resource group>/providers/Microsoft.ManagedIdentity/userAssignedIdentities/myId. Mutually exclusive with identityType systemAssignedIdentity.
 */
public data class CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs(
    public val identityType: Output<CmkIdentityType>? = null,
    public val userAssignedIdentityResourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.fluidrelay.inputs.CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs> {
    override fun toJava():
        com.pulumi.azurenative.fluidrelay.inputs.CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs =
        com.pulumi.azurenative.fluidrelay.inputs.CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs.builder()
            .identityType(identityType?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .userAssignedIdentityResourceId(
                userAssignedIdentityResourceId?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs].
 */
@PulumiTagMarker
public class CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgsBuilder internal
constructor() {
    private var identityType: Output<CmkIdentityType>? = null

    private var userAssignedIdentityResourceId: Output<String>? = null

    /**
     * @param value Values can be SystemAssigned or UserAssigned
     */
    @JvmName("dnmvddkmdffgwyws")
    public suspend fun identityType(`value`: Output<CmkIdentityType>) {
        this.identityType = value
    }

    /**
     * @param value user assigned identity to use for accessing key encryption key Url. Ex: /subscriptions/fa5fc227-a624-475e-b696-cdd604c735bc/resourceGroups/<resource group>/providers/Microsoft.ManagedIdentity/userAssignedIdentities/myId. Mutually exclusive with identityType systemAssignedIdentity.
     */
    @JvmName("tafpuojtqvpsdsxt")
    public suspend fun userAssignedIdentityResourceId(`value`: Output<String>) {
        this.userAssignedIdentityResourceId = value
    }

    /**
     * @param value Values can be SystemAssigned or UserAssigned
     */
    @JvmName("wsprkfypuycckydr")
    public suspend fun identityType(`value`: CmkIdentityType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identityType = mapped
    }

    /**
     * @param value user assigned identity to use for accessing key encryption key Url. Ex: /subscriptions/fa5fc227-a624-475e-b696-cdd604c735bc/resourceGroups/<resource group>/providers/Microsoft.ManagedIdentity/userAssignedIdentities/myId. Mutually exclusive with identityType systemAssignedIdentity.
     */
    @JvmName("dulojbebacaxkjwt")
    public suspend fun userAssignedIdentityResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userAssignedIdentityResourceId = mapped
    }

    internal fun build(): CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs =
        CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs(
            identityType = identityType,
            userAssignedIdentityResourceId = userAssignedIdentityResourceId,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/fluidrelay/kotlin/inputs/CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.fluidrelay.kotlin.inputs

import com.pulumi.azurenative.fluidrelay.inputs.CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs.builder
import com.pulumi.azurenative.fluidrelay.kotlin.enums.CmkIdentityType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * All identity configuration for Customer-managed key settings defining which identity should be used to auth to Key Vault.
 * @property identityType Values can be SystemAssigned or UserAssigned
 * @property userAssignedIdentityResourceId user assigned identity to use for accessing key encryption key Url. Ex: /subscriptions/fa5fc227-a624-475e-b696-cdd604c735bc/resourceGroups/<resource group>/providers/Microsoft.ManagedIdentity/userAssignedIdentities/myId. Mutually exclusive with identityType systemAssignedIdentity.
 */
public data class CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs(
    public val identityType: Output<CmkIdentityType>? = null,
    public val userAssignedIdentityResourceId: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.fluidrelay.inputs.CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs> {
    override fun toJava():
        com.pulumi.azurenative.fluidrelay.inputs.CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs =
        com.pulumi.azurenative.fluidrelay.inputs.CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs.builder()
            .identityType(identityType?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .userAssignedIdentityResourceId(
                userAssignedIdentityResourceId?.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs].
 */
@PulumiTagMarker
public class CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgsBuilder internal
constructor() {
    private var identityType: Output<CmkIdentityType>? = null

    private var userAssignedIdentityResourceId: Output<String>? = null

    /**
     * @param value Values can be SystemAssigned or UserAssigned
     */
    @JvmName("qdeuecdghttvlyse")
    public suspend fun identityType(`value`: Output<CmkIdentityType>) {
        this.identityType = value
    }

    /**
     * @param value user assigned identity to use for accessing key encryption key Url. Ex: /subscriptions/fa5fc227-a624-475e-b696-cdd604c735bc/resourceGroups/<resource group>/providers/Microsoft.ManagedIdentity/userAssignedIdentities/myId. Mutually exclusive with identityType systemAssignedIdentity.
     */
    @JvmName("fsaxircoytwiolda")
    public suspend fun userAssignedIdentityResourceId(`value`: Output<String>) {
        this.userAssignedIdentityResourceId = value
    }

    /**
     * @param value Values can be SystemAssigned or UserAssigned
     */
    @JvmName("yxglomhsxaadqqru")
    public suspend fun identityType(`value`: CmkIdentityType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identityType = mapped
    }

    /**
     * @param value user assigned identity to use for accessing key encryption key Url. Ex: /subscriptions/fa5fc227-a624-475e-b696-cdd604c735bc/resourceGroups/<resource group>/providers/Microsoft.ManagedIdentity/userAssignedIdentities/myId. Mutually exclusive with identityType systemAssignedIdentity.
     */
    @JvmName("xekfmtlnxspqtixh")
    public suspend fun userAssignedIdentityResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userAssignedIdentityResourceId = mapped
    }

    internal fun build(): CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs =
        CustomerManagedKeyEncryptionPropertiesKeyEncryptionKeyIdentityArgs(
            identityType = identityType,
            userAssignedIdentityResourceId = userAssignedIdentityResourceId,
        )
}
